@@ -34,7 +34,11 @@ sub number_of_accounts {
 # Returns this root object.
 #
 sub fetch_root {
-    return Yote::ObjProvider::fetch( 1 );
+    my $root = Yote::ObjProvider::fetch( 1 );
+    unless( $root ) {
+	$root = new Yote::YoteRoot();
+    }
+    return $root;
 }
 
 #
@@ -49,6 +53,7 @@ sub fetch {
     die "Access Error";
 } #fetch
 
+
 #
 # Validates that the given credentials are given
 #   (client side) use : login({h:'handle',p:'password'});
@@ -157,7 +162,7 @@ sub remove_login {
     {
         delete $self->get__handles()->{$args->{h}};
         delete $self->get__emails()->{$args->{e}};
-        $self->add_to_removed_logins( $login );
+        $self->add_to__removed_logins( $login );
         return "deleted account";
     } 
     die "unable to remove account";
